@@ -1,7 +1,4 @@
 import pySPaRTAN.pl
 import pySPaRTAN.pp
 import pySPaRTAN.datasets
-import pySPaRTAN.cythLeastR
-import pySPaRTAN.cythKronPlus
-from pySPaRTAN.pySPaRTAN import SPaRTAN
-
+from pySPaRTAN.pySPaRTAN import SPaRTAN
\ No newline at end of file
